/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @author tags. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */
package org.jboss.test.jsf.injection;

/**
 *
 * @author Stan Silvert ssilvert@redhat.com (C) 2011 Red Hat Inc.
 */
import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.ejb.EJB;
import javax.naming.InitialContext;
import javax.naming.NamingException;

/**
 * Tests resource injection and lifecycle annotations for JSF managed bean.
 *
 * @author Stan Silvert
 */
public class InjectionBean {

    // private DataSource defaultDS;

    @EJB //(name="java:global/SimpleEJB")
    private SimpleEJB simpleEJB;

    private SimpleEJB ejbFromJNDI;

    private boolean postConstructCalled = false;
    private static boolean preDestroyCalled = false;

    /** Creates a new instance of InjectionBean */
    public InjectionBean() throws NamingException {
       ejbFromJNDI = (SimpleEJB)new InitialContext().lookup("java:module/SimpleEJB");
    }

    public String getName() {
        return "InjectionBean";
    }

    public boolean isPreDestroyCalled() {
        return preDestroyCalled;
    }

    public boolean isPostConstructCalled() {
        return postConstructCalled;
    }

    public boolean isEjbInjected() {
      return (simpleEJB != null);
    }

    public boolean isEjbFromJNDI() {
       return (ejbFromJNDI != null);
    }

    @PostConstruct
    private void testPostConstruct() {
        this.postConstructCalled = true;
    }

    @PreDestroy
    public void testPreDestroy() {
        // set the static so that next time you hit the predestroy_postconstruct page, it will return true
        preDestroyCalled = true;
    }
}
